summaryrefslogtreecommitdiff
path: root/inc
diff options
context:
space:
mode:
authorAndreas Gohr <andi@splitbrain.org>2006-02-28 21:48:11 +0100
committerAndreas Gohr <andi@splitbrain.org>2006-02-28 21:48:11 +0100
commitf864871e67a7343d5cdce00da0eb50f8138fba15 (patch)
tree3ed5f19d264eeccff9f77b69fb2fd7ca2e2139b8 /inc
parent4f2e0004f1a19ed841320c7eeac55a1f9fd48c5e (diff)
downloadrpg-f864871e67a7343d5cdce00da0eb50f8138fba15.tar.gz
rpg-f864871e67a7343d5cdce00da0eb50f8138fba15.tar.bz2
unlock a page directly after deletion
This should fix a problem making sweepNS() never work darcs-hash:20060228204811-7ad00-79cca976993d8fa662b94fe683b898985d0dc774.gz
Diffstat (limited to 'inc')
-rw-r--r--inc/common.php6
1 files changed, 4 insertions, 2 deletions
diff --git a/inc/common.php b/inc/common.php
index cef8a0ab0..c321bce82 100644
--- a/inc/common.php
+++ b/inc/common.php
@@ -827,9 +827,11 @@ function saveWikiText($id,$text,$summary,$minor=false){
if (file_exists($mfile)) @unlink($mfile);
}
$del = true;
- //autoset summary on deletion
+ // autoset summary on deletion
if(empty($summary)) $summary = $lang['deleted'];
- //remove empty namespaces
+ // unlock early
+ unlock($id);
+ // remove empty namespaces
io_sweepNS($id);
}else{
// save file (datadir is created in io_saveFile)